pub enum AuthStrategy {
None,
Bearer(String),
}Expand description
Authentication strategy applied to outgoing SDK requests.
Type Safety
Using an enum rather than Option<String> ensures that authentication
modes are explicitly named and exhaustive pattern matching is possible.
Variants
Implementations
Sourceimpl AuthStrategy
impl AuthStrategy
Sourcepub const fn is_configured(&self) -> bool
pub const fn is_configured(&self) -> bool
Returns true if authentication is configured.
Sourcepub const fn bearer_token(&self) -> Option<&String>
pub const fn bearer_token(&self) -> Option<&String>
Returns the bearer token if this strategy is Bearer.