AuthStrategy

Enum AuthStrategy 

pub enum AuthStrategy {
    None,
    Bearer(String),
}
Authentication strategy applied to outgoing SDK requests.

Type Safety

Using an enum rather than Option<String> ensures that authentication modes are explicitly named and exhaustive pattern matching is possible.

Variants



None

Do not attach authentication.



Bearer(String)

Attach an HTTP bearer token.

Implementations

Source

impl AuthStrategy

pub const fn is_configured(&self) -> bool

Returns true if authentication is configured.

pub const fn bearer_token(&self) -> Option<&String>

Returns the bearer token if this strategy is Bearer.